/*
 * Copyright (c) 2018-2020, Dennis Nolte, University of Duisburg-Essen
 * All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without 
 * modification, are permitted provided that the following conditions are met:
 * 1. Redistributions of source code must retain the above copyright notice, 
 * this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright notice, 
 * this list of conditions and the following disclaimer in the documentation 
 * and/or other materials provided with the distribution.
 * 3. Neither the name of the "Theoretical Computer Science, University of
 * Duisburg-Essen, Germany" nor the names of its contributors may be used to 
 * endorse or promote products derived from this software without specific 
 * prior written permission.   
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" 
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE 
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE 
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE 
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR 
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF 
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS 
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN 
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) 
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
 * POSSIBILITY OF SUCH DAMAGE.
 */

package de.uni_due.inf.ti.dragom.data;

/**
 * Class of annotation bounds.
 * 
 * @author Dennis Nolte
 */
public class AnnotationBounds {
	
	private int min;
	private int max;
	
	/**
	 * Standard Constructor for the Standard-Annotation
	 */
	public AnnotationBounds(){
		
		this(1, 1);
	}

	/**
	 * Constructor for any Annotation
	 * @param min The minimal bound
	 * @param max The maximal bound
	 */
	public AnnotationBounds(int min, int max){
		
		this.min = min;
		this.max = max;
	}
	
	/**
	 * Gets the minimal bound of this annotation
	 * @return The minimal bound
	 */
	public int getMin() {
		return min;
	}

	/**
	 * Sets the minimal bound for this annotation
	 * @param min The minimal bound value
	 */
	public void setMin(int min) {
		this.min = min;
	}

	/**
	 * Gets the maximal bound of this annotation
	 * @return The maximal bound
	 */
	public int getMax() {
		return max;
	}

	/**
	 * Sets the maximal bound for this annotation
	 * @param max The maximal bound value
	 */
	public void setMax(int max) {
		this.max = max;
	}
	
}
