/*
 * Copyright (c) 2018-2020, Dennis Nolte, University of Duisburg-Essen
 * All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without 
 * modification, are permitted provided that the following conditions are met:
 * 1. Redistributions of source code must retain the above copyright notice, 
 * this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright notice, 
 * this list of conditions and the following disclaimer in the documentation 
 * and/or other materials provided with the distribution.
 * 3. Neither the name of the "Theoretical Computer Science, University of
 * Duisburg-Essen, Germany" nor the names of its contributors may be used to 
 * endorse or promote products derived from this software without specific 
 * prior written permission.   
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" 
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE 
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE 
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE 
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR 
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF 
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS 
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN 
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) 
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
 * POSSIBILITY OF SUCH DAMAGE.
 */

package de.uni_due.inf.ti.dragom.general;

/**
 * This interface contains static strings with the resource keys to obtain
 * the GUI strings from the GUI resource bundle.
 * 
 * @author Dennis Nolte
 */
public interface ResourceKeys
{
    // Menus
	static final String MENU_SYSTEM 				= "menu.system";
	static final String MENU_ALGORITHM 				= "menu.algorithm";
	static final String MENU_HELP 					= "menu.help";
	
    // General commands
	static final String CMD_ABOUT 					= "cmd.about";
	static final String CMD_ADD_MULTIPLICITY		= "cmd.addmultiplicity";
	static final String CMD_ADD_RULE 				= "cmd.addrule";
	static final String CMD_APPLY 					= "cmd.apply";
	static final String CMD_CANCEL 					= "cmd.cancel";
	static final String CMD_CHECK_INCLUSION 		= "cmd.checkinclusion";
	static final String CMD_CLOSE                   = "cmd.close";
    static final String CMD_COMPUTE					= "cmd.compute";
    static final String CMD_EXIT 					= "cmd.exit";
    static final String CMD_GTS						= "cmd.creategts";
    static final String CMD_GTS_RULE				= "cmd.creategtsrule";
	static final String CMD_INVARIANT_CHECK 		= "cmd.invariantcheck";
	static final String CMD_LOAD					= "cmd.load";
    static final String CMD_MATERIALIZATION			= "cmd.materialization";
    static final String CMD_MAXIMIZE				= "cmd.maximize";
    static final String CMD_NEW						= "cmd.new";
    static final String CMD_NO						= "cmd.no";
    static final String CMD_OKAY					= "cmd.okay";
    static final String CMD_POSTCONDITION			= "cmd.postcondition";
    static final String CMD_PRINT_LANGUAGE			= "cmd.printlanguage";
    static final String CMD_REMOVE_MULTIPLICITY		= "cmd.removemultiplicity";
    static final String CMD_REMOVE_RULE				= "cmd.removerule";
    static final String CMD_RULE					= "cmd.createrule";
    static final String CMD_SAVE					= "cmd.save";
    static final String CMD_SWITCH_MULTIPLICITY		= "cmd.switchmultiplicity";
    static final String CMD_SWITCH_RULE				= "cmd.switchrule";
    static final String CMD_TOGGLE_SIMPLIFY			= "cmd.togglesimplify";
    static final String CMD_TYPE_GRAPH				= "cmd.createtypegraph";
    static final String CMD_USE_THESE_PROPERTIES 	= "cmd.usetheseproperties";
	static final String CMD_WEBSITE 				= "cmd.website";
	static final String CMD_YES						= "cmd.yes";
	
	// Label
	static final String LAB_ANNOTATED_TYPE_GRAPH	= "label.annotatedTypeGraph";
	static final String LAB_CURRENT_RULE			= "label.currentRule";
	static final String LAB_INTERFACE_GRAPH			= "label.interfaceGraph";
	static final String LAB_LEFT_GRAPH				= "label.leftGraph"; 
	static final String LAB_MATERIALIZATION_GRAPH	= "label.materializationGraph";
	static final String LAB_POSTCONDITION_GRAPH		= "label.postconditionGraph";
	static final String LAB_POSTCONDITION_MORPHISM	= "label.postconditionMorphism";
	static final String LAB_RIGHT_GRAPH				= "label.rightGraph";
	static final String LAB_SELECT_ANNOTATION		= "label.selectAnnotation";
	static final String LAB_SELECT_MATCH			= "label.selectMatch"; 
	static final String LAB_SELECT_MORPHISM			= "label.selectMorphism"; 
	static final String LAB_SELECT_RULE				= "label.selectRule";
	static final String LAB_SYSTEMS        	 	    = "label.systems";
	
    // Error messages: general	
	static final String TIT_ERROR 					= "error.title";
    static final String TIT_IOERROR                 = "error.title.io";
    static final String TIT_PARSE_ERROR             = "error.title.parse";

	// File types
    static final String TYPE_GXL_FILE          = "ftype.gxl";
    static final String TYPE_SGF_FILE          = "ftype.sgf";
    
	//------------------------------------------------------------------------
	// Dialog Strings
	//------------------------------------------------------------------------
	
    // About box
    static final String TIT_ABOUT                   = "dlg.about.title";
    static final String MISC_LICENCE                = "dlg.about.cmd.license";
    static final String MISC_LICENCE_TITLE          = "dlg.about.license";
    static final String LABEL_VERSION               = "dlg.about.version";

    // Create rule dialog
	static final String TIT_CREATE_RULE 			= "dlg.createrule.title";
    
    // Create type graph dialog
	static final String TIT_CREATE_TYPE_GRAPH 		= "dlg.createtypegraph.title";

    // Choose base morphism dialog
	static final String TIT_CHOOSE_BASE_MORPHISM 	= "dlg.choosebasemorphism.title";
	
	// Maximize dialog
	static final String TIT_INVARIANT_RESULT 		= "dlg.invariantresult.title";
		
	// Maximize dialog
	static final String TIT_MAXIMIZE 				= "dlg.maximize.title";

	// Switch annotation dialog
	static final String TIT_SWITCH_ANNOTATION 		= "dlg.switchannotation.title";

    // Switch rule dialog
	static final String TIT_SWITCH_RULE 			= "dlg.switchrule.title";
	
}