/*
 * Copyright (c) 2018-2020, Dennis Nolte, University of Duisburg-Essen
 * All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without 
 * modification, are permitted provided that the following conditions are met:
 * 1. Redistributions of source code must retain the above copyright notice, 
 * this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright notice, 
 * this list of conditions and the following disclaimer in the documentation 
 * and/or other materials provided with the distribution.
 * 3. Neither the name of the "Theoretical Computer Science, University of
 * Duisburg-Essen, Germany" nor the names of its contributors may be used to 
 * endorse or promote products derived from this software without specific 
 * prior written permission.   
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" 
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE 
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE 
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE 
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR 
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF 
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS 
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN 
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) 
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
 * POSSIBILITY OF SUCH DAMAGE.
 */

package de.uni_due.inf.ti.dragom.gui;

import java.awt.Color;
import java.awt.Frame;
import java.awt.event.ActionEvent;
import java.io.InputStream;
import java.net.URL;
import java.util.EnumSet;

import javax.swing.BorderFactory;
import javax.swing.Box;
import javax.swing.BoxLayout;
import javax.swing.ImageIcon;
import javax.swing.JButton;
import javax.swing.JComponent;
import javax.swing.JLabel;
import javax.swing.border.BevelBorder;

import de.uni_due.inf.ti.dragom.general.ResourceKeys;
import de.uni_due.inf.ti.dragom.main.Main;
import de.uni_due.inf.ti.gui.CommandTextInfo;
import de.uni_due.inf.ti.swing.GuiContext;
import de.uni_due.inf.ti.swing.StandardAction;
import de.uni_due.inf.ti.swing.StandardDialog;

/**
 * Dialog which displays information about the DrAGoM application.
 * 
 * @author Dennis Nolte
 */
class AboutDialog extends StandardDialog<Void> implements ResourceKeys
{
    private static final long serialVersionUID = -5346791005465206516L;

    public AboutDialog(Frame owner)
    {
        super(owner, TIT_ABOUT, EnumSet.of(Button.ACCEPT));
        setAcceptKey(ResourceKeys.CMD_CLOSE);
    }
    

    /**
     * {@inheritDoc}
     */
    @Override
    protected JComponent getDialogComponent()
    {
        Box box = new Box(BoxLayout.Y_AXIS);
        box.setBackground(Color.WHITE);
        box.setOpaque(true);
        box.setBorder(BorderFactory.createCompoundBorder(
                BorderFactory.createBevelBorder(BevelBorder.LOWERED),
                BorderFactory.createEmptyBorder(20, 20, 20, 20)));
        
        URL imageURL = AboutDialog.class.getResource("/de/uni_due/inf/ti/dragom/resources/logo.png");
        ImageIcon icon = new ImageIcon(imageURL, "DrAGoM, directed graph abstraction over multiplicities");
        box.add(new JLabel(icon));

        String versionKey = GuiContext.getGuiString(LABEL_VERSION);
        String versionText = CommandTextInfo.getCommandText(versionKey, Main.VERSION_ID);
        box.add(new JLabel(versionText));
        
        box.add(Box.createVerticalStrut(10));
        for (String s : Main.COPYRIGHT) {
            box.add(new JLabel(s));
        }
        
        box.add(Box.createVerticalStrut(10));
        box.add(new JButton(new LicenceAction()));

        box.setBorder(BorderFactory.createMatteBorder(1, 1, 1, 1, Color.BLACK));
        
        getContentPane().setBackground(new Color(0,0,0,0));
        getRootPane().setBackground(new Color(0,0,0,0));
        setUndecorated(true);
        setBackground(new Color(0,0,0,0));
        return box;
    }
    
    
    /**
     * Action which displays the license of the program.
     */
    private class LicenceAction extends StandardAction
    {
        public LicenceAction()
        {
            super(ResourceKeys.MISC_LICENCE);
        }

        @Override
        public void actionPerformed(ActionEvent e)
        {
            InputStream in = AboutDialog.class.getResourceAsStream("/de/uni_due/inf/ti/dragom/resources/license.txt");
            String title = GuiContext.getSimpleGuiString(MISC_LICENCE_TITLE);
            DragomInformationDialog dlg = new DragomInformationDialog(AboutDialog.this, title, in); 
            dlg.initialize();
            dlg.runDialog();
        }
    }


}
