/*
 * Copyright (c) 2018-2020, Dennis Nolte, University of Duisburg-Essen
 * All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without 
 * modification, are permitted provided that the following conditions are met:
 * 1. Redistributions of source code must retain the above copyright notice, 
 * this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright notice, 
 * this list of conditions and the following disclaimer in the documentation 
 * and/or other materials provided with the distribution.
 * 3. Neither the name of the "Theoretical Computer Science, University of
 * Duisburg-Essen, Germany" nor the names of its contributors may be used to 
 * endorse or promote products derived from this software without specific 
 * prior written permission.   
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" 
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE 
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE 
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE 
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR 
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF 
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS 
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN 
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) 
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
 * POSSIBILITY OF SUCH DAMAGE.
 */

package de.uni_due.inf.ti.dragom.gui;

import java.awt.Color;
import java.awt.Frame;
import java.util.EnumSet;

import javax.swing.JComponent;
import javax.swing.JScrollPane;
import javax.swing.ScrollPaneConstants;

import de.uni_due.inf.ti.swing.StandardDialog;
import de.uni_due.inf.ti.swing.UserInputException;


/**
 * A dialog which presents information. The user can accept or deny the 
 * displayed option.
 * 
 * @author Dennis Nolte
 */
public class DragomConfirmationDialog extends StandardDialog<Boolean>
{
    private static final long serialVersionUID = -262664487019798230L;
    
    private JComponent infoComponent;
    private boolean commit = false;

    /**
     * Creates a new ConfirmationDialog which shows a custom component containing
     * the information to be shown.
     * 
     * @param owner
     *      owner of the dialog
     * @param title
     *      title of the dialog
     * @param infoComponent
     *      component which displays the information
     */
    public DragomConfirmationDialog(Frame owner, String title, JComponent infoComponent)
    {
        super(owner, title, EnumSet.of(Button.ACCEPT,Button.CANCEL));
        getContentPane().setBackground(new Color(0,0,0,0));
        getRootPane().setBackground(new Color(0,0,0,0));
        setUndecorated(true);
        setBackground(new Color(0,0,0,0));
        setAcceptKey("cmd.yes");
        setCancelKey("cmd.no");
        this.infoComponent = infoComponent;
    }

    /**
     * Sets the key for the Close button. Since, semantically, the Close button
     * is the same as the Cancel button, this method just calls
     * {@link StandardDialog#setCancelKey(String) setCancelKey(key)}
     * @param key The key to be used
     */
    public void setCloseKey(String key)
    {
        setCancelKey(key);
    }

    @Override
    protected Boolean parseOptions() throws UserInputException //TODO
    {
    	commit = true;
        return commit;
    }
    
    /**
     * {@inheritDoc}
     */
    @Override
    protected JComponent getDialogComponent()
    {
        JScrollPane scroll = new JScrollPane(infoComponent);
        scroll.setHorizontalScrollBarPolicy(ScrollPaneConstants.HORIZONTAL_SCROLLBAR_AS_NEEDED);
        scroll.setVerticalScrollBarPolicy(ScrollPaneConstants.VERTICAL_SCROLLBAR_AS_NEEDED);
        return scroll;
    }
    
}
