/*
 * Copyright (c) 2018-2020, Dennis Nolte, University of Duisburg-Essen
 * All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without 
 * modification, are permitted provided that the following conditions are met:
 * 1. Redistributions of source code must retain the above copyright notice, 
 * this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright notice, 
 * this list of conditions and the following disclaimer in the documentation 
 * and/or other materials provided with the distribution.
 * 3. Neither the name of the "Theoretical Computer Science, University of
 * Duisburg-Essen, Germany" nor the names of its contributors may be used to 
 * endorse or promote products derived from this software without specific 
 * prior written permission.   
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" 
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE 
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE 
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE 
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR 
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF 
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS 
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN 
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) 
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
 * POSSIBILITY OF SUCH DAMAGE.
 */

package de.uni_due.inf.ti.dragom.gui;

import javax.swing.filechooser.FileFilter;
import javax.swing.filechooser.FileNameExtensionFilter;

import de.uni_due.inf.ti.dragom.general.ResourceKeys;
import de.uni_due.inf.ti.gui.CommandTextInfo;
import de.uni_due.inf.ti.swing.GuiContext;

/**
 * This class contains utility methods to obtain localized filename filters for
 * various file types used in the DrAGoM application.
 * 
 * @author Dennis Nolte
 */
public class FileTypes
{
    // prohibit instantiation
    private FileTypes() { }

    
    public static enum FileType {
        GXL,
        SGF
    }
    
    
    /**
     * Returns a file filter for a specified file type.
     * 
     * @param type
     *      type for which a FileFilter should be returned
     * @return 
     *      FileFilter for the specified type, or {@code null} if 
     *      {@code type} is {@code null}
     */
    public static FileFilter getFileFilterForType(FileType type)
    {
        switch (type) {
            case GXL: {
                String desc = GuiContext.getSimpleGuiString(ResourceKeys.TYPE_GXL_FILE);
                desc = CommandTextInfo.getCommandText(desc);
                return new FileNameExtensionFilter(desc, "gxl");         
            }
            case SGF: {
                String desc = GuiContext.getSimpleGuiString(ResourceKeys.TYPE_SGF_FILE);
                desc = CommandTextInfo.getCommandText(desc);
                return new FileNameExtensionFilter(desc, "sgf");                
            }
            default:
                return null;
        }
    }
    
}