/*
 * Copyright (c) 2018-2020, Dennis Nolte, University of Duisburg-Essen
 * All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without 
 * modification, are permitted provided that the following conditions are met:
 * 1. Redistributions of source code must retain the above copyright notice, 
 * this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright notice, 
 * this list of conditions and the following disclaimer in the documentation 
 * and/or other materials provided with the distribution.
 * 3. Neither the name of the "Theoretical Computer Science, University of
 * Duisburg-Essen, Germany" nor the names of its contributors may be used to 
 * endorse or promote products derived from this software without specific 
 * prior written permission.   
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" 
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE 
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE 
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE 
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR 
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF 
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS 
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN 
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) 
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
 * POSSIBILITY OF SUCH DAMAGE.
 */

package de.uni_due.inf.ti.dragom.gui;

import java.awt.BorderLayout;
import java.awt.Color;
import java.awt.Dimension;
import java.awt.Frame;
import java.util.EnumSet;

import javax.swing.BorderFactory;
import javax.swing.JComponent;
import javax.swing.JPanel;
import javax.swing.JScrollPane;
import javax.swing.ScrollPaneConstants;

import de.uni_due.inf.ti.dragom.general.ResourceKeys;
import de.uni_due.inf.ti.graph.Morphism;
import de.uni_due.inf.ti.swing.StandardDialog;
import de.uni_due.inf.ti.swing.UserInputException;
import de.uni_due.inf.ti.visigraph.VxGraph;
import de.uni_due.inf.ti.visigraph.swing.GraphPanel;

/**
 * Dialog which displays the inclusion morphism.
 * 
 * @author Dennis Nolte
 */
class InclusionMorphismDialog extends StandardDialog<Morphism>
{
	private static final long serialVersionUID = -4255861163073697037L;
	
	private VxGraph maxGraph;
    private JScrollPane scroll;
	private GraphPanel maxView;

    public InclusionMorphismDialog(Frame owner,VxGraph g)
    {
        super(owner, ResourceKeys.TIT_MAXIMIZE, EnumSet.of(Button.CANCEL));
        setCancelKey(ResourceKeys.CMD_OKAY);

        maxGraph = g;
    }

    /**
     * {@inheritDoc}
     */
    @Override
    protected JComponent getDialogComponent()
    {	
    	JPanel result = new JPanel();
    	result.setPreferredSize(new Dimension((int) (getOwner().getSize().getWidth()*0.85),(int) (getOwner().getSize().getHeight()*0.85))); //new Dimension(1050,700)
    	result.setLayout(new BorderLayout(0,1));
    	result.setOpaque(true);
    	
    	JPanel marginLeft = new JPanel();
    	marginLeft.setPreferredSize(new Dimension(1,700));
    	JPanel marginTop = new JPanel();
    	marginTop.setPreferredSize(new Dimension(1050,1));
    	
    	
    	result.add(marginTop, BorderLayout.NORTH);
    	result.add(marginLeft, BorderLayout.WEST);
        result.add(createMorphismPanel(), BorderLayout.CENTER);
        result.setBorder(BorderFactory.createMatteBorder(1, 1, 1, 1, Color.BLACK));
        
        getContentPane().setBackground(new Color(0,0,0,0));
        getRootPane().setBackground(new Color(0,0,0,0));
        setUndecorated(true);
        setBackground(new Color(0,0,0,0));
        
        return result;
    }

    
    @Override
    protected Morphism parseOptions() throws UserInputException //TODO
    {
        return null;
    }
	
	private JScrollPane createMorphismPanel() {
      
		maxView = new GraphPanel();
        VisiTools.getInstance().getVisualizer().addDefaultStyles(maxView.getDrawer().getStyleMap());
        maxView.setGraph(maxGraph);
		
        scroll = new JScrollPane(maxView);
        scroll.setHorizontalScrollBarPolicy(ScrollPaneConstants.HORIZONTAL_SCROLLBAR_AS_NEEDED);
        scroll.setVerticalScrollBarPolicy(ScrollPaneConstants.VERTICAL_SCROLLBAR_AS_NEEDED);
        
        return scroll;
	}
    
    // ---------------------------------------------------------------------- //
    //                              Informations                              //
    // ---------------------------------------------------------------------- //

	// ---------------------------------------------------------------------- //
    //                              Private Methods                           //
    // ---------------------------------------------------------------------- //

}
