/*
 * Copyright (c) 2018-2020, Dennis Nolte, University of Duisburg-Essen
 * All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without 
 * modification, are permitted provided that the following conditions are met:
 * 1. Redistributions of source code must retain the above copyright notice, 
 * this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright notice, 
 * this list of conditions and the following disclaimer in the documentation 
 * and/or other materials provided with the distribution.
 * 3. Neither the name of the "Theoretical Computer Science, University of
 * Duisburg-Essen, Germany" nor the names of its contributors may be used to 
 * endorse or promote products derived from this software without specific 
 * prior written permission.   
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" 
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE 
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE 
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE 
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR 
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF 
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS 
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN 
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) 
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
 * POSSIBILITY OF SUCH DAMAGE.
 */

package de.uni_due.inf.ti.dragom.io;

import java.util.logging.Logger;

import org.xml.sax.ErrorHandler;
import org.xml.sax.SAXException;
import org.xml.sax.SAXParseException;

/**
 * This class provides an XML error handler which logs parser exception occuring 
 * during processing GXL files.
 * 
 * @author Dennis Nolte
 */
public class GXLErrorHandler implements ErrorHandler {
	
	private final Logger logger;
	
	private boolean errorOccured;
	
	/*------------------------------------------------------------------------------------------*/
	/*		Constructors																		*/
	/*------------------------------------------------------------------------------------------*/
	
	/**
	 * Constructor for the GXLError handler
	 */
	public GXLErrorHandler(){
		errorOccured = false;
		logger = Logger.getLogger(getClass().getName());
	}
	
	/*------------------------------------------------------------------------------------------*/
	/*		Public Methods																		*/
	/*------------------------------------------------------------------------------------------*/
	
	/**
	 * Returns {@code true} if an error occurred.
	 * @return {@code true} if an error occurred, {@code false} otherwise
	 */
	public boolean getErrorOccured(){
		return errorOccured;
	}
	
	@Override
	public void warning(SAXParseException exception)
			throws SAXException {
		logger.throwing(getClass().getName(), "warning", exception);
		System.out.println(exception.getMessage() + "<- warning");
	}

	@Override
	public void fatalError(SAXParseException exception)
			throws SAXException {
		logger.throwing(getClass().getName(), "fatalError", exception);
		System.out.println(exception.getMessage() + "<- fatal error");
		errorOccured = true;
	}

	@Override
	public void error(SAXParseException exception)
			throws SAXException {
		logger.throwing(getClass().getName(), "error", exception);
		System.out.println(exception.getMessage() + "<- error");
		errorOccured = true;
	}
}
