/*
 * Copyright (c) 2018-2020, Dennis Nolte, University of Duisburg-Essen
 * All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without 
 * modification, are permitted provided that the following conditions are met:
 * 1. Redistributions of source code must retain the above copyright notice, 
 * this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright notice, 
 * this list of conditions and the following disclaimer in the documentation 
 * and/or other materials provided with the distribution.
 * 3. Neither the name of the "Theoretical Computer Science, University of
 * Duisburg-Essen, Germany" nor the names of its contributors may be used to 
 * endorse or promote products derived from this software without specific 
 * prior written permission.   
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" 
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE 
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE 
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE 
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR 
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF 
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS 
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN 
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) 
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
 * POSSIBILITY OF SUCH DAMAGE.
 */

package de.uni_due.inf.ti.dragom.main;

import javax.swing.SwingUtilities;

import de.uni_due.inf.ti.dragom.gui.MainFrame;
import de.uni_due.inf.ti.swing.GuiContext;
import de.uni_due.inf.ti.swing.PlatformAdapter;

/**
 * Main class of DrAGoM.
 * 
 * @author Dennis Nolte
 */
public class Main {

    public static final String VERSION_ID           = "1.0";
    public static final String[] COPYRIGHT          = { "(c) 2018-2020 University of Duisburg-Essen", 
                                                        "(c) 2018-2020 Dennis Nolte" };
    
	public static void main(String[] args) {
		
		GuiContext.initialize("de.uni_due.inf.ti.dragom.resources", "en");
		
		PlatformAdapter pa = PlatformAdapter.getInstance();
    	pa.setApplicationName("DrAGoM");
    	pa.initialize();

    	final MainFrame frame = new MainFrame(null,null, false);
        SwingUtilities.invokeLater(() -> {
        	try {
                frame.createAndShowGui();
            }
            catch (Exception e) {
                System.err.println(e.getMessage());
                e.printStackTrace(System.err);
            }
        });
	}

}
