package de.uni_due.inf.ti.graph.visual;

public class GraphSynchronizer extends AbstractGraphSynchronizer
{
    // Properties
    
    /** Whether new binary edges are displayed as arrows. */
    private boolean binaryArrows = false;
    
    /** Name of the style of nodes added by this GraphSynchronizer. */
    private String nodeStyleName = null;
    
    /** Name of the style of hyperedges added by this GraphSynchronizer. */
    private String hyperedgeStyleName = null;
    
    /** Name of the style of edges added by this GraphSynchronizer. */
    private String edgeStyleName = null;
    
    /** Name of the style of connections between nodes and hyperedges that
        are added by this GraphSynchronizer. */
    private String connectionStyleName = null;
    
    /** Name of the style of labels that are added by this GraphSynchronizer. */
    private String labelStyleName = null;
    
    
    /** 
     * Sets whether new edges are displayed as arrows.
     */
    public void setBinaryArrows(boolean ba) 
    {
        binaryArrows = ba;
    }
    
    
    /**
     * Returns whether new edges are displayed as arrows.
     */
    @Override
    public boolean getBinaryArrows()
    {
        return binaryArrows;
    }
    
    
    /**
     * Sets the name of the style used for nodes which are added by this
     * GraphSynchronizer.
     * 
     * @param s
     *      the new node style name
     * @throws NullPointerException
     *      if {@code s == null}
     */
    public void setNodeStyleName(String s)
    {
        if (s == null) throw new NullPointerException();
        nodeStyleName = s;
    }
    
    
    /**
     * Returns the name of the style used for nodes which are added by this
     * GraphSynchronizer.
     */
    @Override
    public String getNodeStyleName()
    {
        return nodeStyleName;
    }

    
    /**
     * Sets the name of the style used for edges which are added by this
     * GraphSynchronizer.
     * 
     * @param s
     *      the new edge style name
     * @throws NullPointerException
     *      if {@code s == null}
     */
    public void setEdgeStyleName(String s)
    {
        if (s == null) throw new NullPointerException();
        edgeStyleName = s;
    }

    
    /**
     * Returns the name of the style used for edges which are added by this
     * GraphSynchronizer.
     */
    @Override
    public String getEdgeStyleName()
    {
        return edgeStyleName;
    }

    
    /**
     * Sets the name of the style used for hyperedges which are added by this
     * GraphSynchronizer.
     * 
     * @param s
     *      the new hyperedge style name
     * @throws NullPointerException
     *      if {@code s == null}
     */
    public void setHyperedgeStyleName(String s)
    {
        if (s == null) throw new NullPointerException();
        hyperedgeStyleName = s;
    }

    
    /**
     * Returns the name of the style used for hyperedges which are added by this
     * GraphSynchronizer.
     */
    @Override
    public String getHyperedgeStyleName()
    {
        return hyperedgeStyleName;
    }


    /**
     * Sets the name of the style used for connections between hyperedges and
     * nodes which are added by this GraphSynchronizer.
     * 
     * @param s
     *      the new connection style name
     * @throws NullPointerException
     *      if {@code s == null}
     */
    public void setConnectionStyleName(String s)
    {
        if (s == null) throw new NullPointerException();
        connectionStyleName = s;
    }

    
    /**
     * Returns the name of the style used for connections which are added by this
     * GraphSynchronizer.
     */
    @Override
    public String getConnectionStyleName()
    {
        return connectionStyleName;
    }

    
    /**
     * Sets the name of the style used for labels which are added by this
     * GraphSynchronizer.
     * 
     * @param s
     *      the new label style name
     * @throws NullPointerException
     *      if {@code s == null}
     */
    public void setLabelStyleName(String s)
    {
        if (s == null) throw new NullPointerException();
        labelStyleName = s;
    }

    
    /**
     * Returns the name of the style used for labels which are added by this
     * GraphSynchronizer.
     */
    @Override
    public String getLabelStyleName()
    {
        return labelStyleName;
    }
}
