package de.uni_due.inf.ti.graph;

import static org.junit.Assert.*;

import java.util.Map;

import org.junit.*;

public class MorphismTest
{
    private TestGraphs tg;
    
    
    private void testMorphismInvariant(Morphism m)
    {
        String morphismName = tg.getName(m);
        
        for (Map.Entry<Edge,Edge> entry : m.getEdgeMap().entrySet()) {
            Edge domEdge = entry.getKey();
            Edge codEdge = entry.getValue();
            assertNotNull("Morphism " + morphismName + " has (one or more) null keys.", domEdge);
            assertNotNull("Morphism " + morphismName + " has (one or more) null values.", codEdge);
            assertTrue("Morphism " + morphismName + " maps an edge to an edge with different arity",
                    domEdge.getNodes().size() == codEdge.getNodes().size());
            assertEquals("Morphism " + morphismName + " maps an edge to an edge with a different label", 
                    domEdge.getLabel(), codEdge.getLabel());
            for (int i = 0; i < domEdge.getNodes().size(); i++) {
                Node domNode = domEdge.getNodes().get(i);
                Node codNode = codEdge.getNodes().get(i);
                assertTrue("Morphism " + morphismName + " does not satisfy morphism invariant",
                        m.get(domNode) == codNode);
            }
        }
    }
    
    private void testTotal(Morphism m, boolean ev)
    {
        String message = String.format("(%s).isTotal() == %b", tg.getName(m), !ev);
        assertTrue(message, m.isTotal() == ev);
    }
    
    private void testSurjective(Morphism m, boolean ev)
    {
        String message = String.format("(%s).isSurjective() == %b", tg.getName(m), !ev);
        assertTrue(message, m.isSurjective() == ev);
    }
    
    private void testIsomorphism(Morphism m, boolean ev)
    {
        String message = String.format("(%s).isIsomorphism() == %b", tg.getName(m), !ev);
        assertTrue(message, m.isIsomorphism() == ev);
    }
    
    
    @Before
    public void generateNewObjects()
    {
        tg = new TestGraphs();
    }

    
    @Test
    public void testMorphisms()
    {
        testMorphismInvariant(tg.morph_AA_A);
        testMorphismInvariant(tg.morph_AB_AbB_1);
        testMorphismInvariant(tg.morph_AB_AbB_2);
    }

    
    @Test
    public void testIsTotal()
    {
        testTotal(tg.morph_AB_AbB_1, true);
        testTotal(tg.morph_AB_AbB_2, true);
        testTotal(tg.morph_AA_A, false);
    }

        
    @Test
    public void testIsSurjective()
    {
        testSurjective(tg.morph_AB_AbB_1, false);
        testSurjective(tg.morph_AB_AbB_2, false);
        testSurjective(tg.morph_AA_A, true);
    }

    
    @Test
    public void testIsIsomorphism()
    {
        testIsomorphism(tg.morph_AB_AbB_1, false);
        testIsomorphism(tg.morph_AB_AbB_2, false);
        testIsomorphism(tg.morph_AA_A, false);
    }
    
    
    @Test
    public void testComposition()
    {
        Morphism compo;
        
        compo = Morphism.createComposition(tg.morph_v_A, tg.match_A_AA_1);
        assertNotNull("Composition 1 == null");
        assertTrue("Composition 1 wrong", compo.equals(tg.morph_v_AA));
    }
}
